@@ -212,6 +212,17 @@ class BuilderTest(object):
             "</Coverage>",
         ]
 
+    def test_buildCoverage_empty(self):
+        # Empty coverage should return an empty Coverage, not None.
+        # https://github.com/fonttools/fonttools/issues/4003
+        cov = builder.buildCoverage([], {"two": 2, "four": 4})
+        assert cov is not None
+        assert cov.glyphs == []
+        assert getXML(cov.toXML) == [
+            "<Coverage>",
+            "</Coverage>",
+        ]
+
     def test_buildCursivePos(self):
         pos = builder.buildCursivePosSubtable(
             {"two": (self.ANCHOR1, self.ANCHOR2), "four": (self.ANCHOR3, self.ANCHOR1)},
@@ -682,6 +693,25 @@ class BuilderTest(object):
     def test_buildMarkGlyphSetsDef_None(self):
         assert builder.buildMarkGlyphSetsDef(None, self.GLYPHMAP) is None
 
+    def test_buildMarkGlyphSetsDef_emptyMarkSet(self):
+        # Empty mark sets should produce an empty Coverage, not None/null offset.
+        # https://github.com/fonttools/fonttools/issues/4003
+        marksets = builder.buildMarkGlyphSetsDef(
+            [{"acute", "grave"}, set()], self.GLYPHMAP
+        )
+        assert getXML(marksets.toXML) == [
+            "<MarkGlyphSetsDef>",
+            '  <MarkSetTableFormat value="1"/>',
+            "  <!-- MarkSetCount=2 -->",
+            '  <Coverage index="0">',
+            '    <Glyph value="grave"/>',
+            '    <Glyph value="acute"/>',
+            "  </Coverage>",
+            '  <Coverage index="1">',
+            "  </Coverage>",
+            "</MarkGlyphSetsDef>",
+        ]
+
     def test_buildMarkLigPosSubtable(self):
         anchor = builder.buildAnchor
         marks = {
