@@ -43,7 +43,8 @@ class RebaseTentTest(object):
                 (0, 0.2, 1),
                 (-1, 0, 0.8),
                 [
-                    (1, (0, 0.25, 1.25)),
+                    (1, (0, 0.25, 1)),
+                    (0.25, (0.25, 1, 1)),
                 ],
             ),
             # Case 3 boundary
@@ -51,7 +52,8 @@ class RebaseTentTest(object):
                 (0, 0.4, 1),
                 (-1, 0, 0.5),
                 [
-                    (1, (0, 0.8, 1.99994)),
+                    (1, (0, 0.8, 1)),
+                    (2.5 / 3, (0.8, 1, 1)),
                 ],
             ),
             # Case 4
@@ -234,7 +236,8 @@ class RebaseTentTest(object):
                 (0, 0.2, 1),
                 (0, 0, 0.5),
                 [
-                    (1, (0, 0.4, 1.99994)),
+                    (1, (0, 0.4, 1)),
+                    (0.625, (0.4, 1, 1)),
                 ],
             ),
             # https://github.com/fonttools/fonttools/issues/3139
